==> bitbucket-api-5.14.1-sources.jar: com/atlassian/bitbucket/project/AbstractProjectRequest.java <==
package com.atlassian.bitbucket.project;

import com.atlassian.bitbucket.util.BuilderSupport;
import org.apache.commons.lang3.StringUtils;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import static com.google.common.base.Preconditions.checkNotNull;
import static com.google.common.base.Preconditions.checkState;

public abstract class AbstractProjectRequest {

    private final String description;
    private final String key;
    private final String name;
    private final String namespace;
    private final boolean publiclyAccessible;

    /**
     * @param builder the builder
     * @since 4.2
     */
    AbstractProjectRequest(AbstractBuilder builder) {
        checkState(StringUtils.isNotBlank(builder.key), "The key of the the project is required");
        checkState(StringUtils.isNotBlank(builder.name), "The name of the project is required");

        description = builder.description;
        name = builder.name;
        namespace = builder.namespace;
        key = builder.key;
        publiclyAccessible = builder.publiclyAccessible;
    }

    /**
     * @return an optional description for the project
     */
    @Nullable
    public String getDescription() {
        return description;
    }

    /**
     * @return the unique key to identify the project, always stored in uppercase
     */
    @Nonnull
    public String getKey() {
        return key;
    }

    /**
     * @return the unique name for the project
     */
    @Nonnull
    public String getName() {
        return name;
    }

    /**
     * @return the namespace for the project
     * @since 4.2
     */
    @Nullable
    public String getNamespace() {
        return namespace;
    }

    /**
     * @return {@code true} if the project will be made publicly accessible, {@code false} otherwise.
     */
    public boolean isPublic() {
        return publiclyAccessible;
    }

    public abstract static class AbstractBuilder<B extends AbstractBuilder> extends BuilderSupport {

        private String description;
        private String key;
        private String name;
        private boolean publiclyAccessible;
        private String namespace;

        protected AbstractBuilder() {
        }

        protected AbstractBuilder(@Nonnull Project project) {
            description = checkNotNull(project, "project").getDescription();
            key = project.getKey();
            name = project.getName();
            namespace = project.getNamespace();
            publiclyAccessible = project.isPublic();
        }

        @Nonnull
        public B description(@Nullable String value) {
            description = value;

            return self();
        }

        @Nonnull
        public B key(@Nonnull String value) {
            key = checkNotNull(value, "key");

            return self();
        }

        @Nonnull
        public B name(@Nonnull String value) {
            name = checkNotNull(value, "name");

            return self();
        }

        /**
         * @param value the namespace
         * @return the builder
         * @since 4.2
         */
        @Nonnull
        public B namespace(@Nullable String value) {
            namespace = value;

            return self();
        }

        /**
         * @param value whether the repository will be publicly accessible or not.
         * @return {@code this}
         */
        @Nonnull
        public B publiclyAccessible(boolean value) {
            publiclyAccessible = value;

            return self();
        }

        @Nonnull
        protected abstract B self();
    }
}

==> bitbucket-api-7.17.0-sources.jar: com/atlassian/bitbucket/project/AbstractProjectRequest.java <==
package com.atlassian.bitbucket.project;

import com.atlassian.bitbucket.util.BuilderSupport;
import org.apache.commons.lang3.StringUtils;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import static java.util.Objects.requireNonNull;
import static com.google.common.base.Preconditions.checkState;

public abstract class AbstractProjectRequest {

    private final String description;
    private final String key;
    private final String name;
    private final String namespace;
    private final boolean publiclyAccessible;

    /**
     * @param builder the builder
     * @since 4.2
     */
    AbstractProjectRequest(AbstractBuilder builder) {
        checkState(StringUtils.isNotBlank(builder.key), "The key of the the project is required");
        checkState(StringUtils.isNotBlank(builder.name), "The name of the project is required");

        description = builder.description;
        name = builder.name;
        namespace = builder.namespace;
        key = builder.key;
        publiclyAccessible = builder.publiclyAccessible;
    }

    /**
     * @return an optional description for the project
     */
    @Nullable
    public String getDescription() {
        return description;
    }

    /**
     * @return the unique key to identify the project, always stored in uppercase
     */
    @Nonnull
    public String getKey() {
        return key;
    }

    /**
     * @return the unique name for the project
     */
    @Nonnull
    public String getName() {
        return name;
    }

    /**
     * @return the namespace for the project
     * @since 4.2
     */
    @Nullable
    public String getNamespace() {
        return namespace;
    }

    /**
     * @return {@code true} if the project will be made publicly accessible, {@code false} otherwise.
     */
    public boolean isPublic() {
        return publiclyAccessible;
    }

    public abstract static class AbstractBuilder<B extends AbstractBuilder> extends BuilderSupport {

        private String description;
        private String key;
        private String name;
        private boolean publiclyAccessible;
        private String namespace;

        protected AbstractBuilder() {
        }

        protected AbstractBuilder(@Nonnull Project project) {
            description = requireNonNull(project, "project").getDescription();
            key = project.getKey();
            name = project.getName();
            namespace = project.getNamespace();
            publiclyAccessible = project.isPublic();
        }

        @Nonnull
        public B description(@Nullable String value) {
            description = value;

            return self();
        }

        @Nonnull
        public B key(@Nonnull String value) {
            key = requireNonNull(value, "key");

            return self();
        }

        @Nonnull
        public B name(@Nonnull String value) {
            name = requireNonNull(value, "name");

            return self();
        }

        /**
         * @param value the namespace
         * @return {@code this}
         * @since 4.2
         */
        @Nonnull
        public B namespace(@Nullable String value) {
            namespace = value;

            return self();
        }

        /**
         * @param value whether the repository will be publicly accessible or not.
         * @return {@code this}
         */
        @Nonnull
        public B publiclyAccessible(boolean value) {
            publiclyAccessible = value;

            return self();
        }

        @Nonnull
        protected abstract B self();
    }
}
